@@ -28,8 +28,9 @@
 #' # Create an empty graph
 #' graph <- create_graph()
 #'
-#' # Create a data frame from which several
-#' # columns have values designated as graph nodes
+#' # Create a data frame from
+#' # which several columns have
+#' # values designated as graph nodes
 #' df <-
 #'   data.frame(
 #'     col_1 = c("f", "p", "q"),
@@ -38,24 +39,21 @@
 #'     col_4 = c("a", "v", "h"),
 #'     stringsAsFactors = FALSE)
 #'
-#' # Add nodes from columns `col_1` and `col_2`
-#' # from the data frame to the graph object
+#' # Add nodes from columns `col_1`
+#' # and `col_2` from the data frame
+#' # to the graph object
 #' graph <-
 #'   graph %>%
 #'   add_nodes_from_df_cols(
 #'     df = df,
 #'     columns = c("col_1", "col_2"))
 #'
-#' # Show the graph's node data frame; duplicate
-#' # labels are prevented with `keep_duplicates =
+#' # Show the graph's node data
+#' # frame; duplicate labels are
+#' # prevented with `keep_duplicates =
 #' # FALSE`)
 #' graph %>%
 #'   get_node_df()
-#' #>   id type label
-#' #> 1  1 <NA>     f
-#' #> 2  2 <NA>     p
-#' #> 3  3 <NA>     q
-#' #> 4  4 <NA>     x
 #'
 #' # Add new nodes from columns 3 and 4;
 #' # We can specify the columns by their
@@ -66,23 +64,15 @@
 #'     df = df,
 #'     columns = 3:4)
 #'
-#' # Show the graph's node data frame; note
-#' # that a nodes didn't get made with columns
-#' # that are not character class columns
+#' # Show the graph's node data
+#' # frame; note that nodes didn't
+#' # get made with columns that
+#' # are not character class columns
 #' graph %>%
 #'   get_node_df()
-#' #>   id type label
-#' #> 1  1 <NA>     f
-#' #> 2  2 <NA>     p
-#' #> 3  3 <NA>     q
-#' #> 4  4 <NA>     x
-#' #> 5  5 <NA>     a
-#' #> 6  6 <NA>     v
-#' #> 7  7 <NA>     h
-#' @importFrom dplyr bind_rows distinct select select_if
+#' @importFrom dplyr bind_rows distinct select select_if as_tibble
 #' @importFrom stringr str_split
 #' @importFrom tidyr drop_na
-#' @importFrom tibble as_tibble
 #' @importFrom purrr flatten_chr
 #' @export add_nodes_from_df_cols
 
@@ -95,9 +85,15 @@ add_nodes_from_df_cols <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Get the df column numbers from which nodes
@@ -107,7 +103,10 @@ add_nodes_from_df_cols <- function(graph,
     # Verify that the none of the values provided
     # are greater than the number of df columns
     if (max(columns) > ncol(df)) {
-      stop("One or more of the column numbers exceeds the number of columns in `df`.")
+
+      emit_error(
+        fcn_name = fcn_name,
+        reasons = "One or more of the column numbers exceeds the number of columns in `df`")
     }
   }
 
@@ -118,14 +117,20 @@ add_nodes_from_df_cols <- function(graph,
     columns <- which(colnames(df) %in% columns)
 
     if (length(columns) < 1) {
-      stop("None of the columns specified are in the `df` object.")
+
+      emit_error(
+        fcn_name = fcn_name,
+        reasons = "None of the columns specified are in the `df` object")
     }
   }
 
+  # Get the number of nodes in the graph
+  nodes_graph_1 <- graph %>% count_nodes()
+
   # Isolate the relevant columns in the data frame;
   # Exclude any columns that are not character class
   df <-
-    tibble::as_tibble(df) %>%
+    dplyr::as_tibble(df) %>%
     dplyr::select(columns) %>%
     dplyr::select_if(is.character)
 
@@ -142,7 +147,7 @@ add_nodes_from_df_cols <- function(graph,
           trimws() %>%
           stringr::str_split(" ") %>%
           purrr::flatten_chr() %>%
-          tibble::as_tibble() %>%
+          dplyr::as_tibble() %>%
           tidyr::drop_na() %>%
           dplyr::distinct() %>%
           purrr::flatten_chr())
@@ -155,7 +160,7 @@ add_nodes_from_df_cols <- function(graph,
   # duplicate labels from being added to the graph
   if (keep_duplicates == FALSE) {
     existing_labels <- graph$nodes_df$label
-    nodes <- setdiff(nodes, existing_labels)
+    nodes <- base::setdiff(nodes, existing_labels)
   }
 
   # Get the number of nodes
@@ -190,16 +195,24 @@ add_nodes_from_df_cols <- function(graph,
     graph$last_node <- graph$last_node + n
   }
 
+  # Get the updated number of nodes in the graph
+  nodes_graph_2 <- graph %>% count_nodes()
+
+  # Get the number of nodes added to
+  # the graph
+  nodes_added <- nodes_graph_2 - nodes_graph_1
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "add_nodes_from_df_cols",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
-      edges = nrow(graph$edges_df))
+      edges = nrow(graph$edges_df),
+      d_n = nodes_added)
 
   # Perform graph actions, if any are available
   if (nrow(graph$graph_actions) > 0) {
