@@ -1,40 +1,53 @@
 #' Combine two graphs into a single graph
-#' @description Combine two graphs in order to make a
-#' new graph.
-#' @param x a \code{DiagrammeR} graph object to which
-#' another graph will be unioned. This graph should be
-#' considered the graph from which global graph
-#' attributes will be inherited in the resulting graph.
-#' @param y a \code{DiagrammeR} graph object that is to
-#' be unioned with the graph supplied as \code{x}.
-#' @return a graph object of class \code{dgr_graph}.
+#' @description Combine two graphs in order
+#' to make a new graph.
+#' @param x a \code{DiagrammeR} graph
+#' object to which another graph will be
+#' unioned. This graph should be considered
+#' the graph from which global graph
+#' attributes will be inherited in the
+#' resulting graph.
+#' @param y a \code{DiagrammeR} graph
+#' object that is to be unioned with the
+#' graph supplied as \code{x}.
+#' @return a graph object of class
+#' \code{dgr_graph}.
 #' @examples
-#' # Create a graph with a cycle with 6 nodes
+#' # Create a graph with a cycle
+#' # containing 6 nodes
 #' graph_cycle <-
 #'  create_graph() %>%
 #'    add_cycle(n = 6)
 #'
-#' # Create a random graph with 8 nodes, 15 edges
+#' # Create a random graph with
+#' # 8 nodes and 15 edges using the
+#' # `add_gnm_graph()` function
 #' graph_random <-
-#'   create_random_graph(
-#'     n = 8, m = 15,
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 8,
+#'     m = 15,
 #'     set_seed = 23)
 #'
-#' # Combine the two graphs in a union operation
+#' # Combine the two graphs in a
+#' # union operation
 #' combined_graph <-
 #'   combine_graphs(
 #'     graph_cycle,
 #'     graph_random)
 #'
-#' # Get the number of nodes in the combined graph
-#' node_count(combined_graph)
-#' #> [1] 14
+#' # Get the number of nodes in
+#' # the combined graph
+#' combined_graph %>%
+#'   count_nodes()
 #'
-#' # The `combine_graphs()` function will renumber
-#' # node ID values in graph `y` during the union;
-#' # this ensures that node ID values are unique
-#' get_node_ids(combined_graph)
-#' #> [1]  1  2  3  4  5  6  7  8  9 10 11 12 13 14
+#' # The `combine_graphs()`
+#' # function will renumber
+#' # node ID values in graph `y`
+#' # during the union; this ensures
+#' # that node ID values are unique
+#' combined_graph %>%
+#'   get_node_ids()
 #' @importFrom dplyr inner_join rename select bind_rows ends_with
 #' @export combine_graphs
 
@@ -44,14 +57,23 @@ combine_graphs <- function(x,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object `x` is valid
   if (graph_object_valid(x) == FALSE) {
-    stop("The graph object `x` is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object supplied to `x` is not valid")
   }
 
   # Validation: Graph object `y` is valid
   if (graph_object_valid(y) == FALSE) {
-    stop("The graph object `y` is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object supplied to `y` is not valid")
   }
 
   # Create bindings for specific variables
@@ -61,10 +83,16 @@ combine_graphs <- function(x,
   # graph `x`
   nodes_created <- x$last_node
 
+  # Get the number of nodes in the graph
+  nodes_graph_1 <- x %>% count_nodes()
+
   # Get the number of edges ever created for
   # graph `x`
   edges_created <- x$last_edge
 
+  # Get the number of edges in the graph
+  edges_graph_1 <- x %>% count_edges()
+
   # Get the node data frame for graph `x`
   x_nodes_df <- get_node_df(x)
 
@@ -124,7 +152,9 @@ combine_graphs <- function(x,
 
   # Rename column names with `.y` suffixes
   colnames(y_edges_df) <-
-    gsub(".y", "", colnames(y_edges_df))
+    gsub(".y$", "", colnames(y_edges_df))
+
+  y_edges_df$id <- y_edges_df$id + edges_created
 
   # Copy new node IDs to `nodes` node attr
   y_nodes_df$id <- y_nodes_df$new_node_id
@@ -151,7 +181,6 @@ combine_graphs <- function(x,
   # from the first graph provided (`x`)
   x$nodes_df <- combined_nodes
   x$edges_df <- combined_edges
-  x$edges_df$id <- as.integer(1:nrow(x$edges_df))
   x$directed <-
     ifelse(
       is_graph_directed(x) == FALSE ||
@@ -160,16 +189,32 @@ combine_graphs <- function(x,
   x$last_node <- nrow(combined_nodes)
   x$last_edge <- nrow(combined_edges)
 
+  # Get the updated number of nodes in the graph
+  nodes_graph_2 <- x %>% count_nodes()
+
+  # Get the number of nodes added to
+  # the graph
+  nodes_added <- nodes_graph_2 - nodes_graph_1
+
+  # Get the updated number of edges in the graph
+  edges_graph_2 <- x %>% count_edges()
+
+  # Get the number of edges added to
+  # the graph
+  edges_added <- edges_graph_2 - edges_graph_1
+
   # Update the `graph_log` df with an action
   x$graph_log <-
     add_action_to_log(
       graph_log = x$graph_log,
       version_id = nrow(x$graph_log) + 1,
-      function_used = "combine_graphs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(x$nodes_df),
-      edges = nrow(x$edges_df))
+      edges = nrow(x$edges_df),
+      d_n = nodes_added,
+      d_e = edges_added)
 
   # Write graph backup if the option is set
   if (x$graph_info$write_backups) {
