@@ -13,50 +13,40 @@
 #' @return a graph object of class
 #' \code{dgr_graph}.
 #' @examples
-#' # Create a random graph
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'   n = 5, m = 8,
-#'   set_seed = 23) %>%
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 5,
+#'     m = 8,
+#'     set_seed = 23) %>%
 #'   set_edge_attrs(
 #'     edge_attr = color,
 #'     values = "green")
 #'
-#' # Get the graph's internal edf to show which
-#' # edge attributes are available
-#' get_edge_df(graph)
-#' #>   id from to  rel color
-#' #> 1  1    2  3 <NA> green
-#' #> 2  2    3  5 <NA> green
-#' #> 3  3    3  4 <NA> green
-#' #> 4  4    2  4 <NA> green
-#' #> 5  5    2  5 <NA> green
-#' #> 6  6    4  5 <NA> green
-#' #> 7  7    1  4 <NA> green
-#' #> 8  8    1  3 <NA> green
+#' # Get the graph's internal
+#' # edf to show which edge
+#' # attributes are available
+#' graph %>%
+#'   get_edge_df()
 #'
-#' # Make a copy the `color` edge attribute as
-#' # the `color_2` edge attribute
+#' # Make a copy the `color`
+#' # edge attribute as the
+#' # `color_2` edge attribute
 #' graph <-
 #'   graph %>%
 #'   copy_edge_attrs(
 #'     edge_attr_from = color,
 #'     edge_attr_to = color_2)
 #'
-#' # Get the graph's internal edf to show that the
-#' # edge attribute had been copied
-#' get_edge_df(graph)
-#' #>   id from to  rel color color_2
-#' #> 1  1    2  3 <NA> green   green
-#' #> 2  2    3  5 <NA> green   green
-#' #> 3  3    3  4 <NA> green   green
-#' #> 4  4    2  4 <NA> green   green
-#' #> 5  5    2  5 <NA> green   green
-#' #> 6  6    4  5 <NA> green   green
-#' #> 7  7    1  4 <NA> green   green
-#' #> 8  8    1  3 <NA> green   green
+#' # Get the graph's internal
+#' # edf to show that the edge
+#' # attribute had been copied
+#' graph %>%
+#'   get_edge_df()
 #' @importFrom dplyr bind_cols
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo get_expr
 #' @export copy_edge_attrs
 
 copy_edge_attrs <- function(graph,
@@ -66,26 +56,40 @@ copy_edge_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  edge_attr_from <- rlang::enquo(edge_attr_from)
-  edge_attr_from <- (rlang::UQ(edge_attr_from) %>% paste())[2]
-
-  edge_attr_to <- rlang::enquo(edge_attr_to)
-  edge_attr_to <- (rlang::UQ(edge_attr_to) %>% paste())[2]
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
+  # Get the requested `edge_attr_from`
+  edge_attr_from <-
+    rlang::enquo(edge_attr_from) %>% rlang::get_expr() %>% as.character()
+
+  # Get the requested `edge_attr_to`
+  edge_attr_to <-
+    rlang::enquo(edge_attr_to) %>% rlang::get_expr() %>% as.character()
+
   # Stop function if `edge_attr_from` and
   # `edge_attr_to` are identical
   if (edge_attr_from == edge_attr_to) {
-    stop("You cannot make a copy with the same name.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot make a copy with the same name")
   }
 
   # Stop function if `edge_attr_to` is `from` or `to`
   if (any(c("from", "to") %in% edge_attr_to)) {
-    stop("You cannot use those names.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot use `from` or `to` as names.")
   }
 
   # Extract the graph's edf
@@ -97,7 +101,10 @@ copy_edge_attrs <- function(graph,
   # Stop function if `edge_attr_from` is not one
   # of the graph's column
   if (!any(column_names_graph %in% edge_attr_from)) {
-    stop("The edge attribute to copy is not in the ndf.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The edge attribute to copy is not in the ndf")
   }
 
   # Get the column number for the edge attr to copy
@@ -123,7 +130,7 @@ copy_edge_attrs <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "copy_edge_attrs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
