@@ -13,44 +13,46 @@
 #' @return a graph object of class
 #' \code{dgr_graph}.
 #' @examples
-#' # Create a random graph
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'     n = 5, m = 10,
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 5,
+#'     m = 10,
 #'     set_seed = 23) %>%
 #'   set_node_attrs(
 #'     node_attr = shape,
-#'     values = "circle")
+#'     values = "circle") %>%
+#'   set_node_attrs(
+#'     node_attr = value,
+#'     values = rnorm(
+#'       n = count_nodes(.),
+#'       mean = 5,
+#'       sd = 1) %>% round(1))
 #'
-#' # Get the graph's internal ndf to show which
-#' # node attributes are available
-#' get_node_df(graph)
-#' #>   id type label value  shape
-#' #> 1  1 <NA>     1   6.0 circle
-#' #> 2  2 <NA>     2   2.5 circle
-#' #> 3  3 <NA>     3   3.5 circle
-#' #> 4  4 <NA>     4   7.5 circle
-#' #> 5  5 <NA>     5   8.5 circle
+#' # Get the graph's internal
+#' # ndf to show which node
+#' # attributes are available
+#' graph %>%
+#'   get_node_df()
 #'
-#' # Make a copy the `value` node attribute as
-#' # the `width` node attribute
+#' # Make a copy the `value`
+#' # node attribute as the
+#' # `width` node attribute
 #' graph <-
 #'   graph %>%
 #'   copy_node_attrs(
 #'     node_attr_from = value,
 #'     node_attr_to = size)
 #'
-#' # Get the graph's internal ndf to show that the
-#' # node attribute had been copied
-#' get_node_df(graph)
-#' #>   id type label value  shape size
-#' #> 1  1 <NA>     1   6.0 circle  6.0
-#' #> 2  2 <NA>     2   2.5 circle  2.5
-#' #> 3  3 <NA>     3   3.5 circle  3.5
-#' #> 4  4 <NA>     4   7.5 circle  7.5
-#' #> 5  5 <NA>     5   8.5 circle  8.5
+#' # Get the graph's internal
+#' # ndf to show that the node
+#' # attribute had been copied
+#' graph %>%
+#'   get_node_df()
 #' @importFrom dplyr bind_cols
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo get_expr
 #' @export copy_node_attrs
 
 copy_node_attrs <- function(graph,
@@ -60,26 +62,40 @@ copy_node_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  node_attr_from <- rlang::enquo(node_attr_from)
-  node_attr_from <- (rlang::UQ(node_attr_from) %>% paste())[2]
-
-  node_attr_to <- rlang::enquo(node_attr_to)
-  node_attr_to <- (rlang::UQ(node_attr_to) %>% paste())[2]
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
+  # Get the requested `node_attr_from`
+  node_attr_from <-
+    rlang::enquo(node_attr_from) %>% rlang::get_expr() %>% as.character()
+
+  # Get the requested `node_attr_to`
+  node_attr_to <-
+    rlang::enquo(node_attr_to) %>% rlang::get_expr() %>% as.character()
+
   # Stop function if `node_attr_from` and
   # `node_attr_to` are identical
   if (node_attr_from == node_attr_to) {
-    stop("You cannot use make a copy with the same name.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot use make a copy with the same name")
   }
 
   # Stop function if `node_attr_to` is `nodes` or `node`
   if (any(c("nodes", "node") %in% node_attr_to)) {
-    stop("You cannot use those names.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot use `nodes` or `node` as names")
   }
 
   # Extract the graph's ndf
@@ -91,7 +107,10 @@ copy_node_attrs <- function(graph,
   # Stop function if `node_attr_from` is not one
   # of the graph's column
   if (!any(column_names_graph %in% node_attr_from)) {
-    stop("The node attribute to copy is not in the ndf.")
+
+    stop(
+      "The node attribute to copy is not in the ndf.",
+      call. = FALSE)
   }
 
   # Get the column number for the node attr to copy
@@ -117,7 +136,7 @@ copy_node_attrs <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "copy_node_attrs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
