@@ -1,10 +1,12 @@
 #' Get the number of asymmetrically-connected node pairs
-#' @description Get the number of asymmetrically-
-#' connected node pairs. This works for directed graphs.
+#' @description Get the number of
+#' asymmetrically-connected node pairs.
+#' This works for directed graphs.
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
-#' @return a single numeric value representing the
-#' number of asymmetrically-connected node pairs.
+#' @return a single numeric value
+#' representing the number of
+#' asymmetrically-connected node pairs.
 #' @examples
 #' # Create a cycle graph
 #' graph <-
@@ -13,8 +15,8 @@
 #'
 #' # Get a count of asymmetrically-
 #' # connected node pairs
-#' count_asymmetric_node_pairs(graph)
-#' #> [1] 5
+#' graph %>%
+#'   count_asymmetric_node_pairs()
 #'
 #' # Create a full graph and then
 #' # count the asymmetrically-
@@ -22,15 +24,20 @@
 #' create_graph() %>%
 #'   add_full_graph(n = 10) %>%
 #'   count_asymmetric_node_pairs()
-#' #> [1] 0
 #' @importFrom igraph dyad_census
 #' @export count_asymmetric_node_pairs
 
 count_asymmetric_node_pairs <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # If the graph is empty, then return NA
