@@ -19,14 +19,14 @@
 #'
 #' # Verify that the node with ID `3`
 #' # is no longer in the graph
-#' get_node_ids(graph)
-#' #> [1] 1 2 4 5
+#' graph %>%
+#'   get_node_ids()
 #'
 #' # Also note that edges are removed
 #' # since there were edges between the
 #' # removed node to and from other nodes
-#' get_edges(graph)
-#' #> [1] "1->2" "4->5"
+#' graph %>%
+#'   get_edges()
 #' @importFrom dplyr filter
 #' @export delete_node
 
@@ -36,14 +36,23 @@ delete_node <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no node can be deleted.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes, so, a node cannot be deleted")
   }
 
   # Create bindings for specific variables
@@ -55,14 +64,26 @@ delete_node <- function(graph,
 
   # Stop function if node not a single value
   if (node_is_single_value == FALSE) {
-    stop("Only a single node can be deleted using `delete_node()`.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "Only a single node can be deleted")
   }
 
   # Stop function if node is not in the graph
   if (!(node %in% get_node_ids(graph))) {
-    stop("The specified node is not available in the graph.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The specified node is not available in the graph")
   }
 
+  # Get the number of nodes in the graph
+  nodes_graph_1 <- graph %>% count_nodes()
+
+  # Get the number of edges in the graph
+  edges_graph_1 <- graph %>% count_edges()
+
   # Get the graph's node data frame
   ndf <- graph$nodes_df
 
@@ -93,16 +114,32 @@ delete_node <- function(graph,
     graph %>%
     remove_linked_dfs()
 
+  # Get the updated number of nodes in the graph
+  nodes_graph_2 <- graph %>% count_nodes()
+
+  # Get the number of nodes added to
+  # the graph
+  nodes_deleted <- nodes_graph_2 - nodes_graph_1
+
+  # Get the updated number of edges in the graph
+  edges_graph_2 <- graph %>% count_edges()
+
+  # Get the number of edges added to
+  # the graph
+  edges_deleted <- edges_graph_2 - edges_graph_1
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "delete_node",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
-      edges = nrow(graph$edges_df))
+      edges = nrow(graph$edges_df),
+      d_n = nodes_deleted,
+      d_e = edges_deleted)
 
   # Perform graph actions, if any are available
   if (nrow(graph$graph_actions) > 0) {
