@@ -32,43 +32,25 @@
 #'   add_edge(from = 4, to = 8)
 #'
 #' # Get a list of all paths outward from node `1`
-#' get_paths(graph, from = 1)
-#' #> [[1]]
-#' #> [1] 1 3 5
-#' #>
-#' #> [[2]]
-#' #> [1] 1 2 7 5
-#' #>
-#' #> [[3]]
-#' #> [1] 1 3 4 6
-#' #>
-#' #> [[4]]
-#' #> [1] 1 3 4 8
+#' graph %>%
+#'   get_paths(from = 1)
 #'
 #' # Get a list of all paths leading to node `6`
-#' get_paths(graph, to = 6)
-#' #> [[1]]
-#' #> [1] 1 3 4 6
+#' graph %>%
+#'   get_paths(to = 6)
 #'
 #' # Get a list of all paths from `1` to `5`
-#' get_paths(graph, from = 1, to = 5)
-#' #> [[1]]
-#' #> [1] 1 3 5
-#' #>
-#' #> [[2]]
-#' #> [1] 1 2 7 5
+#' graph %>%
+#'   get_paths(
+#'    from = 1,
+#'    to = 5)
 #'
 #' # Get a list of all paths from `1` up to a distance
 #' # of 2 node traversals
-#' get_paths(graph, from = 1, distance = 2)
-#' #> [[1]]
-#' #> [1] 1 3 5
-#' #>
-#' #> [[2]]
-#' #> [1] 1 2 7
-#' #>
-#' #> [[3]]
-#' #> [1] 1 3 4
+#' graph %>%
+#'   get_paths(
+#'     from = 1,
+#'     distance = 2)
 #'
 #' # Get a list of the shortest paths from `1` to `5`
 #' get_paths(
@@ -76,8 +58,6 @@
 #'   from = 1,
 #'   to = 5,
 #'   shortest_path = TRUE)
-#' #> [[1]]
-#' #> [1] 1 3 5
 #'
 #' # Get a list of the longest paths from `1` to `5`
 #' get_paths(
@@ -85,8 +65,6 @@
 #'   from = 1,
 #'   to = 5,
 #'   longest_path = TRUE)
-#' #> [[1]]
-#' #> [1] 1 2 7 5
 #' @export get_paths
 
 get_paths <- function(graph,
@@ -96,9 +74,15 @@ get_paths <- function(graph,
                       longest_path = FALSE,
                       distance = NULL) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   reverse_paths <- FALSE
