@@ -43,8 +43,8 @@
 #'
 #' # Verify that the node selection has been made
 #' # using the `get_selection()` function
-#' get_selection(graph)
-#' #> [1] 1 3
+#' graph %>%
+#'   get_selection()
 #'
 #' # Select nodes based on the node `type`
 #' # being `z`
@@ -57,8 +57,8 @@
 #' # Verify that an node selection has been made, and
 #' # recall that the `3` and `4` nodes are of the
 #' # `z` type
-#' get_selection(graph)
-#' #> [1] 3 4
+#' graph %>%
+#'   get_selection()
 #'
 #' # Select edges based on the node value attribute
 #' # being greater than 3.0 (first clearing the current
@@ -72,10 +72,10 @@
 #' # Verify that the correct node selection has been
 #' # made; in this case, nodes `1` and `3` have values
 #' # for `value` greater than 3.0
-#' get_selection(graph)
-#' #> [1] 1 3
+#' graph %>%
+#'   get_selection()
 #' @importFrom dplyr filter pull
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo UQ get_expr
 #' @export select_nodes
 
 select_nodes <- function(graph,
@@ -83,39 +83,59 @@ select_nodes <- function(graph,
                          set_op = "union",
                          nodes = NULL) {
 
-  conditions <- rlang::enquo(conditions)
-
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no selections can be made.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
   # Stop function if `nodes` refers to node ID
   # values that are not in the graph
   if (!is.null(nodes)) {
     if (!any(nodes %in% graph$nodes_df$id)) {
-      stop("The values provided in `nodes` do not all correspond to node ID values in the graph.")
+
+      emit_error(
+        fcn_name = fcn_name,
+        reasons = "The values provided in `nodes` do not all correspond to node ID values in the graph")
     }
   }
 
+  # Capture provided conditions
+  conditions <- rlang::enquo(conditions)
+
   # Create binding for a specific variable
   id <- NULL
 
   # Extract the graph's internal ndf
   nodes_df <- graph$nodes_df
 
+  # Obtain the input graph's node and edge
+  # selection properties
+  n_e_select_properties_in <-
+    node_edge_selection_properties(graph = graph)
+
   # If conditions are provided then
   # pass in those conditions and filter the
   # data frame of `nodes_df`
-  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+  if (!is.null(
+    rlang::enquo(conditions) %>%
+    rlang::get_expr())) {
 
     nodes_df <-
       filter(
@@ -145,7 +165,7 @@ select_nodes <- function(graph,
   } else if (set_op == "intersect") {
     nodes_combined <- intersect(nodes_prev_selection, nodes_selected)
   } else if (set_op == "difference") {
-    nodes_combined <- setdiff(nodes_prev_selection, nodes_selected)
+    nodes_combined <- base::setdiff(nodes_prev_selection, nodes_selected)
   }
 
   # Add the node ID values to the active selection
@@ -158,12 +178,17 @@ select_nodes <- function(graph,
   # Replace `graph$edge_selection` with an empty df
   graph$edge_selection <- create_empty_esdf()
 
+  # Obtain the output graph's node and edge
+  # selection properties
+  n_e_select_properties_out <-
+    node_edge_selection_properties(graph = graph)
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "select_nodes",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
@@ -174,5 +199,43 @@ select_nodes <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
+  # Construct message body
+  if (!n_e_select_properties_in[["node_selection_available"]] &
+      !n_e_select_properties_in[["edge_selection_available"]]) {
+
+    msg_body <-
+      glue::glue(
+        "created a new selection of \\
+         {n_e_select_properties_out[['selection_count_str']]}")
+
+  } else if (n_e_select_properties_in[["node_selection_available"]] |
+             n_e_select_properties_in[["edge_selection_available"]]) {
+
+    if (n_e_select_properties_in[["node_selection_available"]]) {
+      msg_body <-
+        glue::glue(
+          "modified an existing selection of \\
+           {n_e_select_properties_in[['selection_count_str']]}:
+           * {n_e_select_properties_out[['selection_count_str']]} \\
+           are now in the active selection
+           * used the `{set_op}` set operation")
+    }
+
+    if (n_e_select_properties_in[["edge_selection_available"]]) {
+      msg_body <-
+        glue::glue(
+          "created a new selection of \\
+           {n_e_select_properties_out[['selection_count_str']]}:
+           * this replaces \\
+           {n_e_select_properties_in[['selection_count_str']]} \\
+           in the prior selection")
+    }
+  }
+
+  # Issue a message to the user
+  emit_message(
+    fcn_name = fcn_name,
+    message_body = msg_body)
+
   graph
 }
