@@ -17,17 +17,19 @@
 #' @return a graph object of class \code{dgr_graph}.
 #' @examples
 #' # Create a node data frame (ndf)
-#' ndf <- create_node_df(n = 10)
+#' ndf <-
+#'   create_node_df(n = 10)
 #'
 #' # Create a graph
-#' graph <- create_graph(nodes_df = ndf)
+#' graph <-
+#'   create_graph(
+#'     nodes_df = ndf)
 #'
 #' # Select nodes `1` to `5` and show that
 #' # selection of nodes with `get_selection()`
 #' graph %>%
 #'   select_nodes_by_id(nodes = 1:5) %>%
 #'   get_selection()
-#' #> [1] 1 2 3 4 5
 #' @export select_nodes_by_id
 
 select_nodes_by_id <- function(graph,
@@ -37,14 +39,23 @@ select_nodes_by_id <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no selections can be made.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
   # Get a vector of node ID values from the graph
@@ -53,13 +64,21 @@ select_nodes_by_id <- function(graph,
   # Stop function if any nodes specified are not
   # in the graph
   if (any(!(nodes %in% nodes_in_graph))) {
-    stop("One of more of the nodes specified are not available in the graph.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "One of more of the nodes specified are not available in the graph")
   }
 
   # Obtain vector with node ID selection of nodes
   # already present
   nodes_prev_selection <- graph$node_selection$node
 
+  # Obtain the input graph's node and edge
+  # selection properties
+  n_e_select_properties_in <-
+    node_edge_selection_properties(graph = graph)
+
   # Incorporate selected nodes into graph's
   # selection
   if (set_op == "union") {
@@ -70,7 +89,7 @@ select_nodes_by_id <- function(graph,
       intersect(nodes_prev_selection, nodes)
   } else if (set_op == "difference") {
     nodes_combined <-
-      setdiff(nodes_prev_selection, nodes)
+      base::setdiff(nodes_prev_selection, nodes)
   }
 
   # Add the node ID values to the active selection
@@ -83,12 +102,17 @@ select_nodes_by_id <- function(graph,
   # Replace `graph$edge_selection` with an empty df
   graph$edge_selection <- create_empty_esdf()
 
+  # Obtain the output graph's node and edge
+  # selection properties
+  n_e_select_properties_out <-
+    node_edge_selection_properties(graph = graph)
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "select_nodes_by_id",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
@@ -99,5 +123,43 @@ select_nodes_by_id <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
+  # Construct message body
+  if (!n_e_select_properties_in[["node_selection_available"]] &
+      !n_e_select_properties_in[["edge_selection_available"]]) {
+
+    msg_body <-
+      glue::glue(
+        "created a new selection of \\
+        {n_e_select_properties_out[['selection_count_str']]}")
+
+  } else if (n_e_select_properties_in[["node_selection_available"]] |
+             n_e_select_properties_in[["edge_selection_available"]]) {
+
+    if (n_e_select_properties_in[["node_selection_available"]]) {
+      msg_body <-
+        glue::glue(
+          "modified an existing selection of\\
+           {n_e_select_properties_in[['selection_count_str']]}:
+           * {n_e_select_properties_out[['selection_count_str']]}\\
+           are now in the active selection
+           * used the `{set_op}` set operation")
+    }
+
+    if (n_e_select_properties_in[["edge_selection_available"]]) {
+      msg_body <-
+        glue::glue(
+          "created a new selection of\\
+           {n_e_select_properties_out[['selection_count_str']]}:
+           * this replaces\\
+           {n_e_select_properties_in[['selection_count_str']]}\\
+           in the prior selection")
+    }
+  }
+
+  # Issue a message to the user
+  emit_message(
+    fcn_name = fcn_name,
+    message_body = msg_body)
+
   graph
 }
