@@ -11,7 +11,8 @@
 #' # Provide the new graph with a name
 #' graph <-
 #'   graph %>%
-#'   set_graph_name(name = "example_name")
+#'   set_graph_name(
+#'     name = "example_name")
 #' @return a graph object of class \code{dgr_graph}.
 #' @export set_graph_name
 
@@ -21,9 +22,15 @@ set_graph_name <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Set the graph's name
@@ -35,7 +42,7 @@ set_graph_name <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "set_graph_name",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
