@@ -14,10 +14,10 @@
 #' (\code{default}) for all remaining nodes.
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
-#' @param attr the name of the attribute to
-#' set for the \code{type} of global attribute
-#' specified. If set to \code{NULL}, then \code{NA}
-#' values will be assigned to the \code{display}
+#' @param attr the name of the attribute from
+#' which label text for the node will be obtained.
+#' If set to \code{NULL}, then \code{NA} values
+#' will be assigned to the \code{display} column
 #' for the chosen nodes.
 #' @param nodes a length vector containing one or
 #' several node ID values (as integers) for which
@@ -32,14 +32,21 @@
 #' the graph's internal node data frame.
 #' @return a graph object of class \code{dgr_graph}.
 #' @examples
-#' # Create a random graph
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'     n = 5, m = 5,
-#'     set_seed = 23)
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 4,
+#'     m = 4,
+#'     set_seed = 23) %>%
+#'   set_node_attrs(
+#'     node_attr = value,
+#'     values = c(2.5, 8.2, 4.2, 2.4))
 #'
-#' # For node ID values of `1` to `3`, choose
-#' # to display the node `value` attribute (for
+#' # For node ID values of `1`,
+#' # `2`, and `3`, choose to display
+#' # the node `value` attribute (for
 #' # the other nodes, display nothing)
 #' graph <-
 #'   graph %>%
@@ -52,13 +59,8 @@
 #' # `display` node attribute will show for
 #' # each row, which node attribute value to
 #' # display when the graph is rendered
-#' get_node_df(graph)
-#' #>   id type label display value
-#' #> 1  1 <NA>     1   value   6.0
-#' #> 2  2 <NA>     2   value   2.5
-#' #> 3  3 <NA>     3   value   3.5
-#' #> 4  4 <NA>     4    <NA>   7.5
-#' #> 5  5 <NA>     5    <NA>   8.5
+#' graph %>%
+#'   get_node_df()
 #'
 #' # This function can be called multiple
 #' # times on a graph; after the first time
@@ -70,18 +72,12 @@
 #'     nodes = 4,
 #'     attr = label) %>%
 #'   set_node_attr_to_display(
-#'     nodes = c(1, 5),
+#'     nodes = c(1, 3),
 #'     attr = id) %>%
 #'   get_node_df()
-#' #>   id type label display value
-#' #> 1  1 <NA>     1      id   6.0
-#' #> 2  2 <NA>     2   value   2.5
-#' #> 3  3 <NA>     3   value   3.5
-#' #> 4  4 <NA>     4   label   7.5
-#' #> 5  5 <NA>     5      id   8.5
-#' @importFrom dplyr mutate left_join coalesce bind_cols select everything case_when
-#' @importFrom tibble tibble
-#' @importFrom rlang enquo UQ
+#' @importFrom dplyr mutate left_join coalesce bind_cols select
+#' @importFrom dplyr everything case_when tibble
+#' @importFrom rlang enquo get_expr
 #' @export set_node_attr_to_display
 
 set_node_attr_to_display <- function(graph,
@@ -92,33 +88,40 @@ set_node_attr_to_display <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  attr <- rlang::enquo(attr)
-  attr <- (rlang::UQ(attr) %>% paste())[2]
-
-  if (attr == "NULL") {
-    attr <- NULL
-  }
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no selections can be made.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
+  }
+
+  # Get the requested `attr`
+  attr <-
+    rlang::enquo(attr) %>% rlang::get_expr() %>% as.character()
+
+  # If nothing provided for `attr`, set
+  # it as NULL
+  if (length(attr) == 0) {
+    attr <- NULL
   }
 
   # Create bindings for specific variables
   id <- type <- label <- display <- type <- NULL
 
-  # Get the graph's node data frame as an object; stop
-  # function if this doesn't exist
-  if (is.null(graph$nodes_df)) {
-    stop("This graph does not contain any nodes.")
-  } else {
-    ndf <- graph$nodes_df
-  }
+  # Get the graph's node data frame as an object
+  ndf <- graph$nodes_df
 
   # If `nodes` is NULL, assume that all nodes to
   # be assigned a `display` value
@@ -129,14 +132,20 @@ set_node_attr_to_display <- function(graph,
   # Stop function if any of the node ID values
   # provided in `nodes` do not exist in the graph
   if (!any(nodes %in% ndf$id)) {
-    stop("One or more node ID values in `nodes` are not present in the graph.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "One or more node ID values in `nodes` are not present in the graph")
   }
 
   # Stop function if the node attribute supplied as
   # `attr` does not exist in the ndf
   if (!is.null(attr)) {
     if (!(attr %in% colnames(ndf))) {
-      stop("The node attribute given in `attr` is not in the graph's ndf.")
+
+      emit_error(
+        fcn_name = fcn_name,
+        reasons = "The node attribute given in `attr` is not in the graph's ndf")
     }
   }
 
@@ -152,13 +161,13 @@ set_node_attr_to_display <- function(graph,
   # requested node attribute to display
   if (!is.null(attr)) {
     attr_to_display <-
-      tibble::tibble(
+      dplyr::tibble(
         id = as.integer(nodes),
         display = as.character(attr))
 
   } else if (is.null(attr)) {
     attr_to_display <-
-      tibble::tibble(
+      dplyr::tibble(
         id = as.integer(nodes),
         display = as.character("is_na"))
   }
@@ -212,7 +221,7 @@ set_node_attr_to_display <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "set_node_attr_to_display",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
