@@ -15,6 +15,14 @@
 #' traversed edges. If the edge attribute already exists,
 #' the values will be merged to the traversed edges;
 #' otherwise, a new edge attribute will be created.
+#' @param copy_attrs_as if a node attribute name
+#' is provided in \code{copy_attrs_from}, this option
+#' will allow the copied attribute values to be
+#' written under a different edge attribute name.
+#' If the attribute name provided in
+#' \code{copy_attrs_as} does not exist in the graph's
+#' edf, the new edge attribute will be created
+#' with the chosen name.
 #' @return a graph object of class \code{dgr_graph}.
 #' @examples
 #' # Set a seed
@@ -56,22 +64,12 @@
 #'     df = df)
 #'
 #' # Show the graph's internal node data frame
-#' get_node_df(graph)
-#' #>   id type label values
-#' #> 1  1    a   asd    2.3
-#' #> 2  2    a  iekd    4.7
-#' #> 3  3    b   idj    9.4
-#' #> 4  4    b   edl    8.3
-#' #> 5  5    b   ohd    6.3
+#' graph %>%
+#'   get_node_df()
 #'
 #' # Show the graph's internal edge data frame
-#' get_edge_df(graph)
-#' #>   id from to  rel values
-#' #> 1  1    1  2 <NA>   6.00
-#' #> 2  2    1  3    A   6.11
-#' #> 3  3    2  4    B   4.72
-#' #> 4  4    2  5    C   6.02
-#' #> 5  5    3  5    D   5.05
+#' graph %>%
+#'   get_edge_df()
 #'
 #' # Perform a simple traversal from nodes to
 #' # outbound edges with no conditions on the
@@ -80,7 +78,6 @@
 #'   select_nodes_by_id(nodes = 1) %>%
 #'   trav_out_edge() %>%
 #'   get_selection()
-#' #> [1] 1 2
 #'
 #' # Traverse from node `1` to any outbound
 #' # edges, filtering to those edges that have
@@ -90,7 +87,6 @@
 #'   trav_out_edge(
 #'     conditions = is.na(rel)) %>%
 #'   get_selection()
-#' #> [1] 1
 #'
 #' # Traverse from node `3` to any outbound
 #' # edges, filtering to those edges that have
@@ -101,7 +97,6 @@
 #'   trav_out_edge(
 #'     conditions = values > 5.0) %>%
 #'   get_selection()
-#' #> [1] 5
 #'
 #' # Traverse from node `1` to any outbound
 #' # edges, filtering to those edges that
@@ -112,7 +107,6 @@
 #'   trav_out_edge(
 #'     conditions = rel == "A") %>%
 #'   get_selection()
-#' #> [1] 2
 #'
 #' # Traverse from node `2` to any outbound
 #' # edges, filtering to those edges that
@@ -123,7 +117,6 @@
 #'   trav_out_edge(
 #'     conditions = rel %in% c("B", "C")) %>%
 #'   get_selection()
-#' #> [1] 3 4
 #'
 #' # Traverse from node `2` to any
 #' # outbound edges, and use multiple
@@ -135,7 +128,6 @@
 #'       rel %in% c("B", "C") &
 #'       values >= 5.0) %>%
 #'   get_selection()
-#' #> [1] 4
 #'
 #' # Traverse from node `2` to any
 #' # outbound edges, and use multiple
@@ -147,7 +139,6 @@
 #'       rel %in% c("B", "C") |
 #'       values > 6.0) %>%
 #'   get_selection()
-#' #> [1] 3 4
 #'
 #' # Traverse from node `2` to any outbound
 #' # edges, and use a regular expression as
@@ -157,7 +148,6 @@
 #'   trav_out_edge(
 #'     conditions = grepl("B|C", rel)) %>%
 #'   get_selection()
-#' #> [1] 3 4
 #'
 #' # Perform a traversal from all nodes to
 #' # their outgoing edges and, while doing
@@ -173,50 +163,79 @@
 #' # data frame after this change
 #' graph %>%
 #'   get_edge_df()
-#' #>   id from to  rel label values
-#' #> 1  1    1  2 <NA>   asd   6.00
-#' #> 2  1    2  3    A   asd   6.11
-#' #> 3  2    3  4    B  iekd   4.72
-#' #> 4  2    4  5    C  iekd   6.02
-#' #> 5  3    5  5    D   idj   5.05
-#' @importFrom dplyr filter select select_ full_join rename everything
-#' @importFrom rlang enquo UQ
+#' @importFrom dplyr filter select select_ right_join rename everything
+#' @importFrom rlang enquo UQ get_expr
 #' @export trav_out_edge
 
 trav_out_edge <- function(graph,
                           conditions = NULL,
-                          copy_attrs_from = NULL) {
-
-  conditions <- rlang::enquo(conditions)
-
-  copy_attrs_from <- rlang::enquo(copy_attrs_from)
-  copy_attrs_from <- (rlang::UQ(copy_attrs_from) %>% paste())[2]
-
-  if (copy_attrs_from == "NULL") {
-    copy_attrs_from <- NULL
-  }
+                          copy_attrs_from = NULL,
+                          copy_attrs_as = NULL) {
 
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no traversal can occur.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
   # Validation: Graph contains edges
   if (graph_contains_edges(graph) == FALSE) {
-    stop("The graph contains no edges, so, no traversal can occur.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no edges")
   }
 
   # Validation: Graph object has valid node selection
   if (graph_contains_node_selection(graph) == FALSE) {
-    stop("There is no selection of nodes, so, no traversal can occur.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = c(
+        "There is no selection of nodes available.",
+        "any traversal requires an active selection",
+        "this type of traversal requires a selection of nodes"))
+  }
+
+  # Capture provided conditions
+  conditions <- rlang::enquo(conditions)
+
+  # Get the requested `copy_attrs_from`
+  copy_attrs_from <-
+    rlang::enquo(copy_attrs_from) %>% rlang::get_expr() %>% as.character()
+
+  # Get the requested `copy_attrs_as`
+  copy_attrs_as <-
+    rlang::enquo(copy_attrs_as) %>% rlang::get_expr() %>% as.character()
+
+  if (length(copy_attrs_from) == 0) {
+    copy_attrs_from <- NULL
+  }
+
+  if (length(copy_attrs_as) == 0) {
+    copy_attrs_as <- NULL
+  }
+
+  if (!is.null(copy_attrs_as) & !is.null(copy_attrs_from)) {
+    if (copy_attrs_as == copy_attrs_from) {
+      copy_attrs_as <- NULL
+    }
   }
 
   # Create bindings for specific variables
@@ -250,10 +269,12 @@ trav_out_edge <- function(graph,
   # If traversal conditions are provided then
   # pass in those conditions and filter the
   # data frame of `valid_edges`
-  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+  if (!is.null(
+    rlang::enquo(conditions) %>%
+    rlang::get_expr())) {
 
     valid_edges <-
-      filter(
+      dplyr::filter(
         .data = valid_edges,
         rlang::UQ(conditions))
   }
@@ -270,26 +291,39 @@ trav_out_edge <- function(graph,
   # operation
   if (!is.null(copy_attrs_from)) {
 
+    ndf_2 <-
+      ndf %>%
+      dplyr::filter(id %in% starting_nodes) %>%
+      dplyr::select_("id", copy_attrs_from)
+
+    if (!is.null(copy_attrs_as)) {
+
+      if (copy_attrs_as %in% c("id", "from", "to")) {
+
+        emit_error(
+          fcn_name = fcn_name,
+          reasons = "Copied attributes should not overwrite either of the `id`, `from`, or `to` edge attributes")
+      }
+
+      colnames(ndf_2)[2] <- copy_attrs_from <- copy_attrs_as
+    }
+
     # If node attribute doesn't exist in the edf,
     # perform a full join
     if (!(copy_attrs_from %in% colnames(edf))) {
 
       edges <-
-        ndf %>%
-        dplyr::filter(id %in% starting_nodes) %>%
-        dplyr::select_("id", copy_attrs_from) %>%
+        ndf_2 %>%
         dplyr::right_join(edf, c("id" = "from")) %>%
         dplyr::rename(from = id.y) %>%
         dplyr::select(id, from, to, rel, dplyr::everything())
     }
 
-    # If node attribute exists as a column in the edf
+    # If the node attribute exists as a column in the edf
     if (copy_attrs_from %in% colnames(edf)) {
 
       edges <-
-        ndf %>%
-        dplyr::filter(id %in% starting_nodes) %>%
-        dplyr::select_("id", copy_attrs_from) %>%
+        ndf_2 %>%
         dplyr::right_join(edf, c("id" = "from")) %>%
         dplyr::rename(from = id) %>%
         dplyr::rename(id = id.y)
@@ -310,7 +344,7 @@ trav_out_edge <- function(graph,
       }
 
       # Rename the ".y" column
-      colnames(edges)[split_var_y_col] <- copy_attrs_from
+      colnames(edges)[split_var_y_col] <- colnames(ndf_2)[2]
 
       # Drop the ".x" column
       edges <- edges[-split_var_x_col]
@@ -342,7 +376,7 @@ trav_out_edge <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "trav_out_edge",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
