@@ -1,10 +1,13 @@
 context("Community detection algorithms")
 
 test_that("the edge betweeness algorithm is functional", {
-  # Create a random, directed graph with 10 nodes and 15 edges
+
+  # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   # Get the edge betweenness for the graph
@@ -28,12 +31,12 @@ test_that("the edge betweeness algorithm is functional", {
   # are nodes in the graph
   expect_equal(
     nrow(edge_betweeness),
-    node_count(graph))
+    count_nodes(graph = graph))
 
   # For this analysis expect 5 different groups
   expect_equal(
     sort(unique(edge_betweeness$edge_btwns_group)),
-    c(1, 2, 3, 4, 5))
+    c(1, 2, 3, 4, 5, 6))
 
   # Expect the first column to be integer
   expect_is(
@@ -45,10 +48,13 @@ test_that("the edge betweeness algorithm is functional", {
 })
 
 test_that("the fast-greedy algorithm is functional", {
-  # Create a random, directed graph with 10 nodes and 15 edges
+
+  # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 15,
+      m = 10,
       set_seed = 23)
 
   # Get the edge betweenness for the graph
@@ -70,13 +76,13 @@ test_that("the fast-greedy algorithm is functional", {
   # Expect as many rows in the data frame as there
   # are nodes in the graph
   expect_equal(
-    nrow(fast_greedy), node_count(graph))
+    nrow(fast_greedy), count_nodes(graph = graph))
 
   # For this analysis expect two different groups
   # identified with labels `1` and `2`
   expect_equal(
     sort(unique(fast_greedy$f_g_group)),
-    c(1, 2))
+    c(1, 2, 3, 4, 5, 6))
 
   # Expect the first column to be integer
   expect_is(
@@ -88,10 +94,13 @@ test_that("the fast-greedy algorithm is functional", {
 })
 
 test_that("the leading eigenvector algorithm is functional", {
-  # Create a random, directed graph with 10 nodes and 15 edges
+
+  # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   # Get the edge betweenness for the graph
@@ -113,13 +122,13 @@ test_that("the leading eigenvector algorithm is functional", {
   # Expect as many rows in the data frame as there
   # are nodes in the graph
   expect_equal(
-    nrow(l_eigenvec), node_count(graph))
+    nrow(l_eigenvec), count_nodes(graph = graph))
 
   # For this analysis expect two different groups
   # identified with labels `1` and `2`
   expect_equal(
     sort(unique(l_eigenvec$l_eigenvec_group)),
-    c(1, 2))
+    c(1, 2, 3, 4))
 
   # Expect the first column to be integer
   expect_is(
@@ -131,10 +140,12 @@ test_that("the leading eigenvector algorithm is functional", {
 
 test_that("the Louvain algorithm is functional", {
 
-  # Create a random, directed graph with 10 nodes and 15 edges
+  # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   # Get the edge betweenness for the graph
@@ -156,13 +167,13 @@ test_that("the Louvain algorithm is functional", {
   # Expect as many rows in the data frame as there
   # are nodes in the graph
   expect_equal(
-    nrow(louvain), node_count(graph))
+    nrow(louvain), count_nodes(graph = graph))
 
   # For this analysis expect two different groups
   # identified with labels `1` and `2`
   expect_equal(
     sort(unique(louvain$louvain_group)),
-    c(1, 2))
+    c(1, 2, 3, 4))
 
   # Expect the first column to be integer
   expect_is(
@@ -175,10 +186,12 @@ test_that("the Louvain algorithm is functional", {
 
 test_that("the walktrap algorithm is functional", {
 
-  # Create a random, directed graph with 10 nodes and 15 edges
+  # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   # Get the edge betweenness for the graph
@@ -200,13 +213,13 @@ test_that("the walktrap algorithm is functional", {
   # Expect as many rows in the data frame as there
   # are nodes in the graph
   expect_equal(
-    nrow(walktrap), node_count(graph))
+    nrow(walktrap), count_nodes(graph = graph))
 
   # For this analysis expect two different groups
   # identified with labels `1` and `2`
   expect_equal(
     sort(unique(walktrap$walktrap_group)),
-    c(1, 2))
+    c(1, 2, 3, 4))
 
   # Expect the first column to be integer
   expect_is(
