@@ -4,8 +4,10 @@ test_that("Getting betweenness is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   betweenness_vals <- get_betweenness(graph)
@@ -38,8 +40,10 @@ test_that("Getting bridging is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   bridging_vals <- get_bridging(graph)
@@ -72,10 +76,11 @@ test_that("Getting closeness is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
-      set_seed = 23,
-      directed = TRUE)
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
+      set_seed = 23)
 
   # Get closness values with `direction = all`
   closeness_vals_all <- get_closeness(graph)
@@ -154,16 +159,24 @@ test_that("Getting closeness is possible", {
   expect_is(
     closeness_vals_in[, 2],
     "numeric")
+
+  # Expect an error if value for `direction`
+  # is not any of `all`, `in`, or `out`
+  expect_error(
+    get_closeness(
+      graph = graph,
+      direction = "away"))
 })
 
 test_that("Getting coreness values is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
-      set_seed = 23,
-      directed = TRUE)
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
+      set_seed = 23)
 
   # Get coreness values in all directions
   coreness_vals_all <- get_coreness(graph)
@@ -245,16 +258,24 @@ test_that("Getting coreness values is possible", {
   expect_is(
     coreness_vals_out[, 2],
     "numeric")
+
+  # Expect an error if value for `direction`
+  # is not any of `all`, `in`, or `out`
+  expect_error(
+    get_coreness(
+      graph = graph,
+      direction = "away"))
 })
 
 test_that("Getting closeness vitality is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
-      set_seed = 23,
-      directed = TRUE)
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
+      set_seed = 23)
 
   # Get closness vitality values
   closeness_vitality_vals <- get_closeness_vitality(graph)
@@ -286,8 +307,10 @@ test_that("Getting alpha centrality is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 15,
+      m = 15,
       set_seed = 23)
 
   alpha_central_vals <-
@@ -303,12 +326,12 @@ test_that("Getting alpha centrality is possible", {
 
   # Expect 10 rows in the df
   expect_equal(
-    nrow(alpha_central_vals), 10)
+    nrow(alpha_central_vals), 15)
 
   # Expect node ID values in the first column
   expect_identical(
     alpha_central_vals[,1],
-    as.integer(1:10))
+    as.integer(1:15))
 
   # Expect numerical values in the
   # second column
@@ -321,8 +344,10 @@ test_that("Getting leverage centrality is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 10,
       set_seed = 23)
 
   leverage_central_vals <-
@@ -354,33 +379,76 @@ test_that("Getting leverage centrality is possible", {
 
 test_that("Getting authority centrality is possible", {
 
-  set.seed(23)
-
   # Create a random graph
   graph_1 <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
+  # Create a random graph
   graph_2 <-
-    create_random_graph(
-      n = 10, m = 22,
-      set_seed = 1) %>%
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
+      set_seed = 23) %>%
     select_edges() %>%
     set_edge_attrs_ws(
-      edge_attr = "weight",
+      edge_attr = weight,
       value = rnorm(n = 22, mean = 3, sd = 0.5)) %>%
     clear_selection()
 
+  # Create a random graph with non-numeric weights
+  graph_3 <-
+    create_graph() %>%
+    add_gnm_graph(
+      n = 5,
+      m = 6,
+      set_seed = 23) %>%
+    select_edges() %>%
+    set_edge_attrs_ws(
+      edge_attr = weight,
+      value = 1:6 %>% as.character()) %>%
+    clear_selection()
+
+  # Expect an error when the specified
+  # `weights_attr` does not exist in the graph
+  expect_error(
+    graph_2 %>%
+      get_authority_centrality(
+        weights_attr = "weight_2"))
+
+  # Expect an error when the specified
+  # `weights_attr` does not exist in the graph
+  expect_error(
+    graph_2 %>%
+      get_authority_centrality(
+        weights_attr = "weight_2"))
+
+  # Expect an error when the specified
+  # `weights_attr` is not numeric
+  expect_error(
+    graph_3 %>%
+      get_authority_centrality(
+        weights_attr = "weight"))
+
+  # Get values from a graph
+  # without weights
   auth_central_vals <-
     get_authority_centrality(
       graph = graph_1)
 
+  # Get values from a graph
+  # with weights
   auth_central_vals_weight_1 <-
     get_authority_centrality(
       graph = graph_2,
       weights_attr = "weight")
 
+  # Get values from a graph
+  # with weights (w/o specifying the column)
   auth_central_vals_weight_2 <-
     get_authority_centrality(graph = graph_2)
 
@@ -448,29 +516,74 @@ test_that("Getting eigenvector centrality is possible", {
 
   # Create a random graph
   graph_1 <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
+  # Create a random graph
   graph_2 <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23) %>%
     select_edges() %>%
     set_edge_attrs_ws(
-      edge_attr = "weight",
+      edge_attr = weight,
       value = rnorm(n = 22, mean = 3, sd = 0.5)) %>%
     clear_selection()
 
+  # Create a random graph with non-numeric weights
+  graph_3 <-
+    create_graph() %>%
+    add_gnm_graph(
+      n = 5,
+      m = 6,
+      set_seed = 23) %>%
+    select_edges() %>%
+    set_edge_attrs_ws(
+      edge_attr = weight,
+      value = 1:6 %>% as.character()) %>%
+    clear_selection()
+
+  # Expect an error when the specified
+  # `weights_attr` does not exist in the graph
+  expect_error(
+    graph_2 %>%
+    get_eigen_centrality(
+      weights_attr = "weight_2"))
+
+  # Expect an error when the specified
+  # `weights_attr` does not exist in the graph
+  expect_error(
+    graph_2 %>%
+      get_eigen_centrality(
+        weights_attr = "weight_2"))
+
+  # Expect an error when the specified
+  # `weights_attr` is not numeric
+  expect_error(
+    graph_3 %>%
+      get_eigen_centrality(
+        weights_attr = "weight"))
+
+  # Get values from a graph
+  # without weights
   eigen_central_vals <-
     get_eigen_centrality(
       graph = graph_1)
 
+  # Get values from a graph
+  # with weights
   eigen_central_vals_weight_1 <-
     get_eigen_centrality(
       graph = graph_2,
       weights_attr = "weight")
 
+  # Get values from a graph
+  # with weights (w/o specifying the column)
   eigen_central_vals_weight_2 <-
     get_eigen_centrality(graph = graph_2)
 
@@ -536,8 +649,10 @@ test_that("Getting constraint values is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
   # Get constraint values for all
@@ -607,8 +722,10 @@ test_that("Getting radiality values is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
   # Get constraint values for all
@@ -644,37 +761,37 @@ test_that("Getting radiality values is possible", {
     get_radiality(
       graph = graph,
       direction = "all")[, 2] %>% min(),
-    2.5)
+    2.1111)
 
   expect_lte(
     get_radiality(
       graph = graph,
       direction = "all")[, 2] %>% max(),
-    3.3)
+    3.1111)
 
   expect_gte(
     get_radiality(
       graph = graph,
       direction = "in")[, 2] %>% min(),
-    0.4)
+    3.4444)
 
   expect_lte(
     get_radiality(
       graph = graph,
       direction = "in")[, 2] %>% max(),
-    2.8)
+    4.6667)
 
   expect_gte(
     get_radiality(
       graph = graph,
       direction = "out")[, 2] %>% min(),
-    0.4)
+    0.6667)
 
   expect_lte(
     get_radiality(
       graph = graph,
       direction = "out")[, 2] %>% max(),
-    2.5)
+    5.2222)
 
   # Expect an error if using a `direction`
   # value that isn't valid
@@ -688,8 +805,10 @@ test_that("Getting PageRank values is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 10, m = 22,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
   # Get constraint values for all
@@ -724,8 +843,10 @@ test_that("Getting articulation points is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 30, m = 50,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
   # Get articulation points for the graph
@@ -738,15 +859,17 @@ test_that("Getting articulation points is possible", {
 
   # Expect 4 values in the vector
   expect_equal(
-    length(articulation_points), 7)
+    length(articulation_points), 2)
 })
 
 test_that("Getting weakly connected components is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 30, m = 50,
+    create_graph() %>%
+    add_gnm_graph(
+      n = 10,
+      m = 22,
       set_seed = 23)
 
   # Get connected components for the graph
@@ -763,7 +886,7 @@ test_that("Getting weakly connected components is possible", {
 
   # Expect 30 rows in the df
   expect_equal(
-    nrow(connected_components), 30)
+    nrow(connected_components), 10)
 
   # Expect numerical values in the
   # second column
@@ -776,10 +899,11 @@ test_that("Getting strongly connected components is possible", {
 
   # Create a random graph
   graph <-
-    create_random_graph(
-      n = 5, m = 10,
-      set_seed = 23,
-      directed = TRUE)
+    create_graph() %>%
+    add_gnm_graph(
+      n = 5,
+      m = 10,
+      set_seed = 23)
 
   # Get connected components for the graph
   s_connected_components <-
