@@ -14,7 +14,8 @@ test_that("the specification tools are functional", {
   replaced_spec <- grViz(replace_in_spec(spec))
 
   # Expect that the object inherits from 'grViz' and 'htmlwidget'
-  expect_is(replaced_spec, c("grViz", "htmlwidget"))
+  expect_is(
+    replaced_spec, c("grViz", "htmlwidget"))
 
   # Create a simple Graphviz graph specification and perform
   # substitution using a vector
@@ -41,5 +42,6 @@ test_that("the specification tools are functional", {
   replaced_spec <- grViz(replace_in_spec(spec))
 
   # Expect that the object inherits from 'grViz' and 'htmlwidget'
-  expect_is(replaced_spec, c("grViz", "htmlwidget"))
+  expect_is(
+    replaced_spec, c("grViz", "htmlwidget"))
 })
